View source: R/DemographicTable.R
| DemographicTable | R Documentation |
To create a demographic table with simple summary statistics, with optional comparison(s) over one or more groups.
DemographicTable(data, data.name = substitute(data), by = NULL, ...)
data |
a data.frame |
data.name |
character scalar,
or the argument call of |
by |
one-sided formula,
the name(s) of sub-group(s) for which the summary statistics are provided.
Default |
... |
additional parameters, currently not in use |
A demographic table with simple summary statistics, with optional comparison(s) over one or more groups, is created.
numeric variables are summarized in means, standard deviations, medians, inter-quartile-ranges (IQR),
p-value of Shapiro-Wilk normality test and ranges.
If group is specified, they are compared using two-sample t.test,
wilcox.test (Wilcoxon / Mann-Whitney), one-way aov (ANOVA) and/or
kruskal.test (Kruskal-Wallis).
logical and factor variables are summarized in counts and percentages.
If group is specified, they are compared using prop.test (chi-squared)
and/or fisher.test (Fisher's exact).
The function DemographicTable() returns an object of S3 class 'DemographicTable',
which is a listof 'sumtab' elements.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.