| sumstat | R Documentation |
Summary statistics to be presented in a DemographicTable.
.sumstat(x, fmt, ...)
## Default S3 method:
.sumstat(x, fmt = "%.2f", ...)
## S3 method for class 'factor'
.sumstat(x, ...)
## S3 method for class 'character'
.sumstat(x, ...)
## S3 method for class 'logical'
.sumstat(x, ...)
x |
an R object |
fmt |
(optional) character scalar, only for the function |
... |
additional parameters, currently not in use |
The function .sumstat.default() accepts all R objects of typeof double and integer.
Statistics of mean, sd and range are reported.
If the normality assumption via shapiro.test is not satisfied, then median and mad are also reported.
The function .sumstat() returns a character scalar.
airquality$Solar.R |> .sumstat()
state.region |> .sumstat()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.